==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_fields/CLAUSEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CLAUSEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CLAUSEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLAUSECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CLAUSEID_Type", propOrder = {
    "clausecode",
    "organizationid",
    "description"
})
public class CLAUSEID_Type {

    @XmlElement(name = "CLAUSECODE", required = true)
    protected String clausecode;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété clausecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCLAUSECODE() {
        return clausecode;
    }

    /**
     * Définit la valeur de la propriété clausecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCLAUSECODE(String value) {
        this.clausecode = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/CLAUSEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CLAUSEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CLAUSEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLAUSECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CLAUSEID_Type", propOrder = {
    "clausecode",
    "organizationid",
    "description"
})
public class CLAUSEID_Type {

    @XmlElement(name = "CLAUSECODE", required = true)
    protected String clausecode;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the clausecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCLAUSECODE() {
        return clausecode;
    }

    /**
     * Sets the value of the clausecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCLAUSECODE(String value) {
        this.clausecode = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
